@@ -13,3 +13,5 @@ from blinker import Signal
 
 
 message_received = Signal()
+queue_size_updated = Signal('queue_size')
+meshtastic_connected = Signal('meshtastic_connected')
